Parser

Struct Parser 

pub struct Parser<'s> {
    pub filepath: PathBuf,
    pub source_code: &'s str,
    pub root: DocumentFunction,
}
Parser holds a reference to the text document source code. To generate better error messages, we also store the filepath. The parsing process fills a tree with data.

A typical parsing process is done with the following methods: consume_iter(iter) takes a LexingIterator and consumes the generated tokens. Then finalize declares the termination of the token consumption. Finally one can fetch the resulting abstract syntax tree by calling the method tree().

Fields

filepath: PathBufsource_code: &'s strroot: DocumentFunction

Implementations

Source

impl<'s> Parser<'s>

pub fn new(filepath: &Path, source_code: &'s str) -> Parser<'s>

pub fn consume_iter(&mut self, iter: LexingIterator<'_>) -> Result<(), Error>

Consumes the tokens provided by the LexingIterator argument

pub fn finalize(&mut self) -> Result<(), Error>

Declares the end of the text document

pub fn tree(self) -> DocumentTree

Returns the Abstract Syntax Tree to be processed further