pub struct DocumentFunction {
pub call: String,
pub args: HashMap<String, DocumentNode>,
pub content: DocumentNode,
}Expand description
DocumentFunction is a function call in the text document. For example,
{text[style=bold] message} is a DocumentFunction with name “text”,
args such that style is associated with DocumentNode::Text “bold”
and content is given as DocumentNode::Text “message”.
Fields
call: Stringargs: HashMap<String, DocumentNode>content: DocumentNodeImplementations
Sourceimpl DocumentFunction
impl DocumentFunction
Sourcepub fn new() -> DocumentFunction
pub fn new() -> DocumentFunction
Returns an empty DocumentFunction without args or content and name is set to “”.
Sourcepub fn empty_element() -> DocumentElement
pub fn empty_element() -> DocumentElement
Returns an empty DocumentElement::Function without args or content and name is set to “”.